@@ -22,7 +22,10 @@ of stack usage.
 
 import xdis.opcodes.opcode_26 as opcode_26
 from xdis.opcodes.base import (
-    finalize_opcodes, init_opdata,
+    extended_format_ATTR,
+    extended_format_RETURN_VALUE,
+    finalize_opcodes,
+    init_opdata,
     jrel_op, name_op, nargs_op, varargs_op,
     update_pj2
     )
@@ -51,3 +54,9 @@ jrel_op(l, 'JUMP_IF_NOT_DEBUG',      204, conditional=True)
 update_pj2(globals(), l)
 
 finalize_opcodes(l)
+
+opcode_extended_fmt = {
+    "LOAD_ATTR": extended_format_ATTR,
+    "RETURN_VALUE": extended_format_RETURN_VALUE,
+    "STORE_ATTR": extended_format_ATTR,
+}
